@@ -3,7 +3,7 @@
 # Project: AutoArchive
 # License: GNU GPLv3
 #
-# Copyright (C) 2003 - 2014 Róbert Čerňanský
+# Copyright (C) 2003 - 2022 Róbert Čerňanský
 
 
 
@@ -22,14 +22,14 @@ class AppEnvironment:
 
     :param executableName: Name of the startup script.
     :type executableName: ``str``
-    :param options: Options passed on the command line.
-    :type options: :class:`optparse.Values`
+    :param commandLineOptions: Options passed on the command line.
+    :type commandLineOptions: ``collections.abc.Mapping``
     :param arguments: Arguments passed on the command line.
     :type arguments: ``list<str>``"""
 
-    def __init__(self, executableName, options, arguments):
+    def __init__(self, executableName, commandLineOptions, arguments):
         self.__executableName = executableName
-        self.__options = options
+        self.__commandLineOptions = commandLineOptions
         self.__arguments = arguments
 
 
@@ -45,12 +45,12 @@ class AppEnvironment:
 
 
     @property
-    def options(self):
+    def commandLineOptions(self):
         """Command line options.
 
-        :rtype: ``optparse.Values``"""
+        :rtype: ``collections.abc.Mapping``"""
 
-        return self.__options
+        return self.__commandLineOptions
 
 
 
